/*
	nc.c - simple CLI to-do list

	This file is part of nc.

	nc is free software: you can redistribute it and/or modify it
	under the terms of the GNU General Public License as published by the
	Free Software Foundation, either version 3 of the License, or (at your
	option) any later version.

	nc is distributed in the hope that it will be useful, but WITHOUT
	ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
	FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
	for more details.

	You should have received a copy of the GNU General Public License
	along with nc. If not, see <https://www.gnu.org/licenses/>. 
*/

#include <libcolor.h>
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>

#include "nc.h"

#include "config.h" /* for outputting NC_EVENTS_FILE */

static void
usage(int argc, char *argv[])
{
	printf("%s - simple CLI to-do list\n", argv[0]);
	printf("usage: %s [-h] [-v] [-s] [-n] [-l]\n", argv[0]);
	printf("\n");
	printf("%s {-h}			Show this message\n", argv[0]);
	printf("%s {-v}			Show the current version\n", argv[0]);
	printf("%s {-s}			View compile-time settings\n", argv[0]);
	printf("%s {-n}	DATE NAME	Create a new event\n", argv[0]);
	printf("%s {-l}			Show current events\n", argv[0]);
	printf("\n");
	printf("Nc is free software.\n");
	printf("See the GNU GPL version 3 for details.\n");
}

static void
usage_small(int argc, char *argv[])
{
	printf("usage: %s [-h] [-v] [-s] [-n] [-l]\n", argv[0]);
}

static void
view_compile_time_settings(int argc, char *argv[])
{
	printf("Compile-time settings for %s\n", argv[0]);
	printf("Events file: " NC_EVENTS_FILE "\n");
}

int main(int argc, char *argv[]) {

	if (argc < 2) {
		usage_small(argc, argv);
		exit(1);
	}

	int opt;

	while ((opt = getopt(argc, argv, ":if:hvsnl")) != -1) {
		switch(opt) {
		case 'h':
			usage(argc, argv);
			exit(0);
			break;
		case 'v':
			printf(NC_VERSION "\n");
			exit(0);
			break;
		case 's':
			view_compile_time_settings(argc, argv);
			exit(0);
			break;
		case 'n':
			mkevent(argc, argv);
			break;
		case 'l':
			printevents();
			break;
		case '?':
			usage_small(argc, argv);
			exit(1);
			break;
		}
	}

	return 0;
}
